==> glfw3_3.3.10.orig.tar.gz: glfw-3.3.10/CONTRIBUTORS.md <==
# Acknowledgements

GLFW exists because people around the world donated their time and lent their
skills.  This list only includes contributions to the main repository and
excludes other invaluable contributions like language bindings and text and
video tutorials.

 - Bobyshev Alexander
 - Laurent Aphecetche
 - Matt Arsenault
 - Takuro Ashie
 - ashishgamedev
 - David Avedissian
 - Keith Bauer
 - John Bartholomew
 - Coşku Baş
 - Niklas Behrens
 - Andrew Belt
 - Nevyn Bengtsson
 - Niklas Bergström
 - Denis Bernard
 - BiBi
 - Doug Binks
 - blanco
 - Waris Boonyasiriwat
 - Kyle Brenneman
 - Rok Breulj
 - TheBrokenRail
 - Kai Burjack
 - Martin Capitanio
 - Nicolas Caramelli
 - David Carlier
 - Arturo Castro
 - Chi-kwan Chan
 - TheChocolateOre
 - Joseph Chua
 - Ian Clarkson
 - Michał Cichoń
 - Lambert Clara
 - Anna Clarke
 - Josh Codd
 - Yaron Cohen-Tal
 - Omar Cornut
 - Andrew Corrigan
 - Bailey Cosier
 - Noel Cower
 - CuriouserThing
 - Bill Currie
 - Jason Daly
 - danhambleton
 - Jarrod Davis
 - Olivier Delannoy
 - Paul R. Deppe
 - Michael Dickens
 - Роман Донченко
 - Mario Dorn
 - Wolfgang Draxinger
 - Jonathan Dummer
 - Ralph Eastwood
 - Fredrik Ehnbom
 - Robin Eklind
 - Jan Ekström
 - Siavash Eliasi
 - TheExileFox
 - Nikita Fediuchin
 - Felipe Ferreira
 - Michael Fogleman
 - forworldm
 - Jason Francis
 - Gerald Franz
 - Mário Freitas
 - GeO4d
 - Marcus Geelnard
 - Gegy
 - ghuser404
 - Charles Giessen
 - Ryan C. Gordon
 - Stephen Gowen
 - Kovid Goyal
 - Kevin Grandemange
 - Eloi Marín Gratacós
 - Grzesiek11
 - Stefan Gustavson
 - Andrew Gutekanst
 - Stephen Gutekanst
 - Jonathan Hale
 - Daniel Hauser
 - hdf89shfdfs
 - Moritz Heinemann
 - Sylvain Hellegouarch
 - Björn Hempel
 - Matthew Henry
 - heromyth
 - Lucas Hinderberger
 - Paul Holden
 - Hajime Hoshi
 - Warren Hu
 - Charles Huber
 - Brent Huisman
 - illustris
 - InKryption
 - IntellectualKitty
 - Aaron Jacobs
 - JannikGM
 - Erik S. V. Jansson
 - jjYBdx4IL
 - Peter Johnson
 - Toni Jovanoski
 - Arseny Kapoulkine
 - Cem Karan
 - Osman Keskin
 - Koray Kilinc
 - Josh Kilmer
 - Byunghoon Kim
 - Cameron King
 - Peter Knut
 - Christoph Kubisch
 - Yuri Kunde Schlesner
 - Rokas Kupstys
 - Konstantin Käfer
 - Eric Larson
 - Francis Lecavalier
 - Jong Won Lee
 - Robin Leffmann
 - Glenn Lewis
 - Shane Liesegang
 - Anders Lindqvist
 - Leon Linhart
 - Marco Lizza
 - lo-v-ol
 - Eyal Lotem
 - Aaron Loucks
 - Ned Loynd
 - Luflosi
 - lukect
 - Tristam MacDonald
 - Jean-Luc Mackail
 - Hans Mackowiak
 - Ramiro Magno
 - Дмитри Малышев
 - Zbigniew Mandziejewicz
 - Adam Marcus
 - Célestin Marot
 - Kyle McDonald
 - David V. McKay
 - David Medlock
 - Bryce Mehring
 - Jonathan Mercier
 - Marcel Metz
 - Liam Middlebrook
 - Ave Milia
 - Icyllis Milica
 - Jonathan Miller
 - Kenneth Miller
 - Bruce Mitchener
 - Jack Moffitt
 - Ravi Mohan
 - Jeff Molofee
 - Alexander Monakov
 - Pierre Morel
 - Jon Morton
 - Pierre Moulon
 - Martins Mozeiko
 - James Murphy
 - Julian Møller
 - NateIsStalling
 - ndogxj
 - F. Nedelec
 - Kristian Nielsen
 - Joel Niemelä
 - Kamil Nowakowski
 - onox
 - Denis Ovod
 - Ozzy
 - Andri Pálsson
 - Peoro
 - Braden Pellett
 - Christopher Pelloux
 - Arturo J. Pérez
 - Vladimir Perminov
 - Olivier Perret
 - Anthony Pesch
 - Orson Peters
 - Emmanuel Gil Peyrot
 - Cyril Pichard
 - Pilzschaf
 - Keith Pitt
 - Stanislav Podgorskiy
 - Konstantin Podsvirov
 - Nathan Poirier
 - Alexandre Pretyman
 - Pablo Prietz
 - przemekmirek
 - pthom
 - Martin Pulec
 - Guillaume Racicot
 - Christian Rauch
 - Philip Rideout
 - Eddie Ringle
 - Max Risuhin
 - Joe Roback
 - Jorge Rodriguez
 - Luca Rood
 - Ed Ropple
 - Aleksey Rybalkin
 - Mikko Rytkönen
 - Riku Salminen
 - Anton Samokhvalov
 - Brandon Schaefer
 - Sebastian Schuberth
 - Christian Sdunek
 - Matt Sealey
 - Steve Sexton
 - Arkady Shapkin
 - Mingjie Shen
 - Ali Sherief
 - Yoshiki Shibukawa
 - Dmitri Shuralyov
 - Joao da Silva
 - Daniel Sieger
 - Michael Skec
 - Daniel Skorupski
 - Slemmie
 - Bradley Smith
 - Cliff Smolinsky
 - Patrick Snape
 - Erlend Sogge Heggen
 - Olivier Sohn
 - Julian Squires
 - Johannes Stein
 - Pontus Stenetorp
 - Michael Stocker
 - Justin Stoecker
 - Elviss Strazdins
 - Paul Sultana
 - Nathan Sweet
 - TTK-Bandit
 - Nuno Teixeira
 - Sergey Tikhomirov
 - Arthur Tombs
 - TronicLabs
 - Ioannis Tsakpinis
 - Samuli Tuomola
 - Matthew Turner
 - urraka
 - Elias Vanderstuyft
 - Stef Velzel
 - Jari Vetoniemi
 - Ricardo Vieira
 - Nicholas Vitovitch
 - Vladimír Vondruš
 - Simon Voordouw
 - Corentin Wallez
 - Torsten Walluhn
 - Patrick Walton
 - Jim Wang
 - Xo Wang
 - Jay Weisskopf
 - Frank Wille
 - Richard A. Wilkes
 - Andy Williams
 - Tatsuya Yatagawa
 - Ryogo Yoshimura
 - Rácz Zalán
 - Lukas Zanner
 - Andrey Zholos
 - Aihui Zhu
 - Santi Zupancic
 - Jonas Ådahl
 - Lasse Öörni
 - Leonard König
 - All the unmentioned and anonymous contributors in the GLFW community, for bug
   reports, patches, feedback, testing and encouragement

==> glfw3_3.4.orig.tar.gz: glfw-3.4/CONTRIBUTORS.md <==
# Acknowledgements

GLFW exists because people around the world donated their time and lent their
skills.  This list only includes contributions to the main repository and
excludes other invaluable contributions like language bindings and text and
video tutorials.

 - Bobyshev Alexander
 - Laurent Aphecetche
 - Matt Arsenault
 - Takuro Ashie
 - ashishgamedev
 - David Avedissian
 - Luca Bacci
 - Keith Bauer
 - John Bartholomew
 - Coşku Baş
 - Bayemite
 - Niklas Behrens
 - Andrew Belt
 - Nevyn Bengtsson
 - Niklas Bergström
 - Denis Bernard
 - BiBi
 - Doug Binks
 - blanco
 - Waris Boonyasiriwat
 - Kyle Brenneman
 - Rok Breulj
 - TheBrokenRail
 - Kai Burjack
 - Martin Capitanio
 - Nicolas Caramelli
 - David Carlier
 - Arturo Castro
 - Chi-kwan Chan
 - Victor Chernyakin
 - TheChocolateOre
 - Ali Chraghi
 - Joseph Chua
 - Ian Clarkson
 - Michał Cichoń
 - Lambert Clara
 - Anna Clarke
 - Josh Codd
 - Yaron Cohen-Tal
 - Omar Cornut
 - Andrew Corrigan
 - Bailey Cosier
 - Noel Cower
 - CuriouserThing
 - Bill Currie
 - Jason Daly
 - danhambleton
 - Jarrod Davis
 - Olivier Delannoy
 - Paul R. Deppe
 - Michael Dickens
 - Роман Донченко
 - Mario Dorn
 - Wolfgang Draxinger
 - Jonathan Dummer
 - Ralph Eastwood
 - Fredrik Ehnbom
 - Robin Eklind
 - Jan Ekström
 - Siavash Eliasi
 - Ahmad Fatoum
 - Nikita Fediuchin
 - Felipe Ferreira
 - Michael Fogleman
 - forworldm
 - Jason Francis
 - Gerald Franz
 - Mário Freitas
 - GeO4d
 - Marcus Geelnard
 - Gegy
 - ghuser404
 - Charles Giessen
 - Ryan C. Gordon
 - Stephen Gowen
 - Kovid Goyal
 - Kevin Grandemange
 - Eloi Marín Gratacós
 - Grzesiek11
 - Stefan Gustavson
 - Andrew Gutekanst
 - Stephen Gutekanst
 - Jonathan Hale
 - Daniel Hauser
 - hdf89shfdfs
 - Moritz Heinemann
 - Sylvain Hellegouarch
 - Björn Hempel
 - Matthew Henry
 - heromyth
 - Lucas Hinderberger
 - Paul Holden
 - Hajime Hoshi
 - Warren Hu
 - Charles Huber
 - Brent Huisman
 - Florian Hülsmann
 - illustris
 - InKryption
 - IntellectualKitty
 - Aaron Jacobs
 - JannikGM
 - Erik S. V. Jansson
 - jjYBdx4IL
 - Peter Johnson
 - Toni Jovanoski
 - Arseny Kapoulkine
 - Cem Karan
 - Osman Keskin
 - Koray Kilinc
 - Josh Kilmer
 - Byunghoon Kim
 - Cameron King
 - Peter Knut
 - Christoph Kubisch
 - Yuri Kunde Schlesner
 - Rokas Kupstys
 - Konstantin Käfer
 - Eric Larson
 - Guillaume Lebrun
 - Francis Lecavalier
 - Jong Won Lee
 - Robin Leffmann
 - Glenn Lewis
 - Shane Liesegang
 - Anders Lindqvist
 - Leon Linhart
 - Marco Lizza
 - lo-v-ol
 - Eyal Lotem
 - Aaron Loucks
 - Ned Loynd
 - Luflosi
 - lukect
 - Tristam MacDonald
 - Jean-Luc Mackail
 - Hans Mackowiak
 - Ramiro Magno
 - Дмитри Малышев
 - Zbigniew Mandziejewicz
 - Adam Marcus
 - Célestin Marot
 - Kyle McDonald
 - David V. McKay
 - David Medlock
 - Bryce Mehring
 - Jonathan Mercier
 - Marcel Metz
 - Liam Middlebrook
 - mightgoyardstill
 - Ave Milia
 - Icyllis Milica
 - Jonathan Miller
 - Kenneth Miller
 - Bruce Mitchener
 - Jack Moffitt
 - Ravi Mohan
 - Jeff Molofee
 - Alexander Monakov
 - Pierre Morel
 - Jon Morton
 - Pierre Moulon
 - Martins Mozeiko
 - Pascal Muetschard
 - James Murphy
 - Julian Møller
 - Julius Häger
 - Nat!
 - NateIsStalling
 - ndogxj
 - F. Nedelec
 - n3rdopolis
 - Kristian Nielsen
 - Joel Niemelä
 - Victor Nova
 - Kamil Nowakowski
 - onox
 - Denis Ovod
 - Ozzy
 - Andri Pálsson
 - luz paz
 - Peoro
 - Braden Pellett
 - Christopher Pelloux
 - Michael Pennington
 - Arturo J. Pérez
 - Vladimir Perminov
 - Olivier Perret
 - Anthony Pesch
 - Orson Peters
 - Emmanuel Gil Peyrot
 - Cyril Pichard
 - Pilzschaf
 - Keith Pitt
 - Stanislav Podgorskiy
 - Konstantin Podsvirov
 - Nathan Poirier
 - Pokechu22
 - Alexandre Pretyman
 - Pablo Prietz
 - przemekmirek
 - pthom
 - Martin Pulec
 - Guillaume Racicot
 - Juan Ramos
 - Christian Rauch
 - Philip Rideout
 - Eddie Ringle
 - Max Risuhin
 - Joe Roback
 - Jorge Rodriguez
 - Jari Ronkainen
 - Luca Rood
 - Ed Ropple
 - Aleksey Rybalkin
 - Mikko Rytkönen
 - Riku Salminen
 - Yoshinori Sano
 - Brandon Schaefer
 - Sebastian Schuberth
 - Scr3amer
 - Jan Schuerkamp
 - Christian Sdunek
 - Matt Sealey
 - Steve Sexton
 - Arkady Shapkin
 - Mingjie Shen
 - Ali Sherief
 - Yoshiki Shibukawa
 - Dmitri Shuralyov
 - Joao da Silva
 - Daniel Sieger
 - Daljit Singh
 - Michael Skec
 - Daniel Skorupski
 - Slemmie
 - Anthony Smith
 - Bradley Smith
 - Cliff Smolinsky
 - Patrick Snape
 - Erlend Sogge Heggen
 - Olivier Sohn
 - Julian Squires
 - Johannes Stein
 - Pontus Stenetorp
 - Michael Stocker
 - Justin Stoecker
 - Elviss Strazdins
 - Paul Sultana
 - Nathan Sweet
 - TTK-Bandit
 - Nuno Teixeira
 - Jared Tiala
 - Sergey Tikhomirov
 - Arthur Tombs
 - TronicLabs
 - Ioannis Tsakpinis
 - Samuli Tuomola
 - Matthew Turner
 - urraka
 - Elias Vanderstuyft
 - Stef Velzel
 - Jari Vetoniemi
 - Ricardo Vieira
 - Nicholas Vitovitch
 - Vladimír Vondruš
 - Simon Voordouw
 - Corentin Wallez
 - Torsten Walluhn
 - Patrick Walton
 - Jim Wang
 - Xo Wang
 - Andre Weissflog
 - Jay Weisskopf
 - Frank Wille
 - Andy Williams
 - Joel Winarske
 - Richard A. Wilkes
 - Tatsuya Yatagawa
 - Ryogo Yoshimura
 - Lukas Zanner
 - Andrey Zholos
 - Aihui Zhu
 - Santi Zupancic
 - Jonas Ådahl
 - Lasse Öörni
 - Leonard König
 - All the unmentioned and anonymous contributors in the GLFW community, for bug
   reports, patches, feedback, testing and encouragement
